==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMRuleDataSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JVMRuleDataSpecFluentImpl<A extends JVMRuleDataSpecFluent<A>> extends BaseFluent<A> implements JVMRuleDataSpecFluent<A>{
  public JVMRuleDataSpecFluentImpl() {
  }
  public JVMRuleDataSpecFluentImpl(JVMRuleDataSpec instance) {
    this.withPid(instance.getPid()); 
    this.withPort(instance.getPort()); 
    this.withRuleData(instance.getRuleData()); 
  }
  private Integer pid;
  private Integer port;
  private String ruleData;
  public Integer getPid() {
    return this.pid;
  }
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  public Boolean hasPid() {
    return this.pid != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public String getRuleData() {
    return this.ruleData;
  }
  public A withRuleData(String ruleData) {
    this.ruleData=ruleData; return (A) this;
  }
  public Boolean hasRuleData() {
    return this.ruleData != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    JVMRuleDataSpecFluentImpl that = (JVMRuleDataSpecFluentImpl) o;
    if (pid != null ? !pid.equals(that.pid) :that.pid != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (ruleData != null ? !ruleData.equals(that.ruleData) :that.ruleData != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(pid,  port,  ruleData,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (ruleData != null) { sb.append("ruleData:"); sb.append(ruleData); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMRuleDataSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JVMRuleDataSpecFluentImpl<A extends JVMRuleDataSpecFluent<A>> extends BaseFluent<A> implements JVMRuleDataSpecFluent<A>{
  public JVMRuleDataSpecFluentImpl() {
  }
  public JVMRuleDataSpecFluentImpl(JVMRuleDataSpec instance) {
    if (instance != null) {
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
      this.withRuleData(instance.getRuleData());
    }
  }
  private Integer pid;
  private Integer port;
  private String ruleData;
  public Integer getPid() {
    return this.pid;
  }
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  public Boolean hasPid() {
    return this.pid != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public String getRuleData() {
    return this.ruleData;
  }
  public A withRuleData(String ruleData) {
    this.ruleData=ruleData; return (A) this;
  }
  public Boolean hasRuleData() {
    return this.ruleData != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMRuleDataSpecFluentImpl that = (JVMRuleDataSpecFluentImpl) o;
    if (!java.util.Objects.equals(pid, that.pid)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    if (!java.util.Objects.equals(ruleData, that.ruleData)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(pid,  port,  ruleData,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (ruleData != null) { sb.append("ruleData:"); sb.append(ruleData); }
    sb.append("}");
    return sb.toString();
  }
  
}
